import { renderless, api } from '@opentinyvue/vue-renderless/drawer/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { IconClose } from '@opentinyvue/vue-icon';
import Button from '@opentinyvue/vue-button';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    IconClose: IconClose()
  },
  props: [].concat(props, ["visible", "title", "showHeader", "showFooter", "customClass", "placement", "width", "mask", "dragable", "maskClosable", "lockScroll", "flex", "beforeClose"]),
  emits: ["update:visible", "open", "close", "confirm"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "text-sm",
    attrs: {
      "data-tag": "tiny-drawer"
    }
  }, [_vm.mask ? _c("div", {
    ref: "mask",
    class: _vm.m("fixed z-50 left-0 right-0 top-0 bottom-0 w-full h-full transition ease-linear duration-200", {
      "bg-color-bg-7": _vm.state.visible
    }),
    on: {
      "click": function click($event) {
        return _vm.handleClose("mask");
      }
    }
  }) : _vm._e(), _c("div", {
    ref: "drawerBox",
    class: _vm.m("fixed w-full max-w-full flex flex-col bg-color-bg-1 z-50 shadow-sm border-color-border-separator", {
      "transition-all ease-linear duration-200": !_vm.state.dragEvent.isDrag
    }, {
      "h-full": ["left", "right"].includes(_vm.placement)
    }, {
      "max-h-full": ["top", "bottom"].includes(_vm.placement)
    }, {
      "left-0 bottom-0 translate-y-full border-t-0.5 rounded-t-lg": _vm.placement === "bottom"
    }, {
      "left-0 top-0 -translate-y-full border-b-0.5 rounded-b-lg": _vm.placement === "top"
    }, {
      "translate-y-0": ["top", "bottom"].includes(_vm.placement) && _vm.state.visible
    }, {
      "left-0 top-0 -translate-x-full border-r-0.5 rounded-r-lg": _vm.placement === "left"
    }, {
      "right-0 top-0 translate-x-full border-l-0.5 rounded-l-lg": _vm.placement === "right"
    }, {
      "translate-x-0": ["left", "right"].includes(_vm.placement) && _vm.state.visible
    }, _vm.customClass),
    style: {
      width: ["left", "right"].includes(_vm.placement) ? _vm.state.computedWidth : null,
      height: ["top", "bottom"].includes(_vm.placement) && _vm.dragable && _vm.state.height ? _vm.state.height + "px" : null
    },
    attrs: {
      "data-tag": "tiny-drawer-main"
    }
  }, [_vm.dragable ? _c("div", {
    ref: "dragBar",
    class: ["absolute", ["left", "right"].includes(_vm.placement) && "cursor-e-resize h-full top-0 w-2", ["top", "bottom"].includes(_vm.placement) && "cursor-n-resize w-full h-2 left-0", _vm.placement === "left" && "-right-1", _vm.placement === "right" && "-left-1", _vm.placement === "top" && "-bottom-1", _vm.placement === "bottom" && "-top-1"],
    attrs: {
      "data-tag": "drawer-drag-bar"
    }
  }) : _vm._e(), _c("div", {
    class: ["flex-auto flex-col flex max-h-full overflow-hidden"]
  }, [_vm.showHeader ? _c("div", {
    ref: "header",
    staticClass: "flex-none flex leading-6 p-4 text-base items-center",
    attrs: {
      "data-tag": "drawer-header"
    }
  }, [_vm._t("header", function() {
    return [_vm.title ? _c("div", {
      staticClass: "max-w-[80%] pr-4 text-left truncate text-color-text-primary"
    }, [_vm._v(_vm._s(_vm.title))]) : _vm._e(), _c("div", {
      staticClass: "flex-1 flex items-center justify-end"
    }, [_vm._t("header-right", function() {
      return [_c("IconClose", {
        staticClass: "fill-color-icon-primary",
        attrs: {
          "custom-class": "h-5 w-5 cursor-pointer"
        },
        on: {
          "click": function click($event) {
            return _vm.handleClose("close");
          }
        }
      })];
    })], 2)];
  })], 2) : _vm._e(), _c("div", {
    ref: "body",
    class: ["flex-auto overflow-auto", {
      "flex flex-col": _vm.flex
    }],
    attrs: {
      "data-tag": "drawer-body"
    }
  }, [_vm._t("default")], 2), _vm.showFooter ? _c("div", {
    ref: "footer",
    staticClass: "px-4 py-3",
    attrs: {
      "data-tag": "drawer-footer"
    }
  }, [_c("div", {
    staticClass: "flex-1 text-right"
  }, [_vm._t("footer", function() {
    return [_c("tiny-button", {
      attrs: {
        "tiny_mode": "mobile-first"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClose("cancel");
        }
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.cancel")))]), _c("tiny-button", {
      staticClass: "ml-2",
      attrs: {
        "tiny_mode": "mobile-first",
        "type": "primary"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClose("confirm");
        }
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])];
  })], 2)]) : _vm._e()])])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
