import { renderless, api } from '@opentinyvue/vue-renderless/drawer/vue';
import { defineComponent, h, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme/drawer/index.css';
import { iconClose, iconHelpCircle } from '@opentinyvue/vue-icon';
import Button from '@opentinyvue/vue-button';
import Tooltip from '@opentinyvue/vue-tooltip';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    TinyTooltip: Tooltip,
    IconClose: iconClose(),
    IconHelpCircle: iconHelpCircle(),
    // tiny新增: 适配Vue2下, 在模板中渲染VNode
    SlotWrapper: {
      props: ["node"],
      render: function render() {
        var node = this.node;
        if (typeof node === "function") {
          return node(h);
        } else {
          return node;
        }
      }
    }
  },
  props: [].concat(props, ["visible", "title", "showHeader", "showFooter", "customClass", "placement", "width", "height", "mask", "dragable", "maskClosable", "lockScroll", "flex", "showClose", "zIndex", "beforeClose", "tipsProps", "customSlots"]),
  emits: ["update:visible", "open", "close", "confirm", "drag"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render2 = function render3() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-drawer",
    attrs: {
      "data-tag": "tiny-drawer"
    }
  }, [_c("transition", {
    attrs: {
      "name": "drawer-fade"
    }
  }, [_vm.mask && _vm.state.visible ? _c("div", {
    ref: "mask",
    staticClass: "tiny-drawer__mask show-bg-color",
    style: {
      zIndex: _vm.zIndex
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("mask");
      }
    }
  }) : _vm._e()]), _c("transition", {
    attrs: {
      "name": "drawer-slide-" + _vm.placement
    }
  }, [_c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.visible,
      expression: "state.visible"
    }],
    ref: "drawerBox",
    class: ["tiny-drawer__main", {
      "is-left": _vm.placement === "left",
      "is-right": _vm.placement === "right",
      "is-top": _vm.placement === "top",
      "is-bottom": _vm.placement === "bottom",
      "drag-effects": !_vm.state.dragEvent.isDrag,
      "toggle": _vm.state.visible
    }, "tiny-drawer-main", _vm.customClass],
    style: {
      width: ["left", "right"].includes(_vm.placement) ? _vm.state.computedWidth : null,
      height: ["top", "bottom", "left", "right"].includes(_vm.placement) || _vm.dragable ? _vm.state.computedHeight : null,
      zIndex: _vm.zIndex
    },
    attrs: {
      "data-tag": "tiny-drawer-main"
    }
  }, [_vm.dragable ? _c("div", {
    ref: "dragBar",
    class: ["tiny-drawer__drag-bar", ["left", "right"].includes(_vm.placement) && "p-left-Right", ["top", "bottom"].includes(_vm.placement) && "p-top-Bottom", _vm.placement === "left" && "p-left", _vm.placement === "right" && "p-right", _vm.placement === "top" && "p-top", _vm.placement === "bottom" && "p-bottom"],
    attrs: {
      "data-tag": "drawer-drag-bar"
    }
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-drawer__box"
  }, [_vm.showHeader ? _c("div", {
    ref: "header",
    staticClass: "tiny-drawer__header-wrapper",
    attrs: {
      "data-tag": "drawer-header"
    }
  }, [_vm._t("header", function() {
    var _vm$customSlots;
    return [(_vm$customSlots = _vm.customSlots) !== null && _vm$customSlots !== void 0 && _vm$customSlots.header ? _c("slot-wrapper", {
      attrs: {
        "node": _vm.customSlots.header
      }
    }) : _c("div", {
      staticClass: "tiny-drawer__header"
    }, [_c("div", {
      staticClass: "tiny-drawer__header-left"
    }, [_vm.title ? _c("div", {
      staticClass: "tiny-drawer__title"
    }, [_vm._v(_vm._s(_vm.title))]) : _vm._e(), _vm.tipsProps ? _c("tiny-tooltip", _vm._b({}, "tiny-tooltip", _vm.tipsProps, false), [_c("icon-help-circle", {
      staticClass: "tiny-drawer__help-icon"
    })], 1) : _vm._e()], 1), _c("div", {
      staticClass: "tiny-drawer__header-right"
    }, [_vm._t("header-right", function() {
      var _vm$customSlots2;
      return [(_vm$customSlots2 = _vm.customSlots) !== null && _vm$customSlots2 !== void 0 && _vm$customSlots2.headerRight ? _c("slot-wrapper", {
        attrs: {
          "node": _vm.customSlots.headerRight
        }
      }) : _vm._e()];
    })], 2)])];
  }), _vm.showClose ? _c("button", {
    staticClass: "tiny-drawer__headerbtn",
    attrs: {
      "type": "button",
      "aria-label": "Close"
    },
    on: {
      "click": function click($event) {
        return _vm.handleClose("close");
      }
    }
  }, [_c("icon-close", {
    staticClass: "tiny-svg-size tiny-drawer__close"
  })], 1) : _vm._e()], 2) : _vm._e(), _c("div", {
    ref: "body",
    class: ["tiny-drawer__body", {
      "flex flex-col": _vm.flex
    }, "drawer-body"],
    attrs: {
      "data-tag": "drawer-body"
    }
  }, [_vm._t("default", function() {
    var _vm$customSlots3;
    return [_c("slot-wrapper", {
      attrs: {
        "node": (_vm$customSlots3 = _vm.customSlots) === null || _vm$customSlots3 === void 0 ? void 0 : _vm$customSlots3.default
      }
    })];
  })], 2), _vm.showFooter ? _c("div", {
    ref: "footer",
    staticClass: "tiny-drawer__footer",
    attrs: {
      "data-tag": "drawer-footer"
    }
  }, [_vm._t("footer", function() {
    var _vm$customSlots4;
    return [(_vm$customSlots4 = _vm.customSlots) !== null && _vm$customSlots4 !== void 0 && _vm$customSlots4.footer ? _c("slot-wrapper", {
      attrs: {
        "node": _vm.customSlots.footer
      }
    }) : [_c("tiny-button", {
      staticClass: "tiny-drawer__cancel-btn",
      attrs: {
        "plain": ""
      },
      on: {
        "click": function click($event) {
          return _vm.handleClose("cancel");
        }
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.cancel")))]), _c("tiny-button", {
      staticClass: "tiny-drawer__confirm-btn",
      attrs: {
        "type": "primary"
      },
      on: {
        "click": function click($event) {
          return _vm.handleClose("confirm");
        }
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])]];
  })], 2) : _vm._e()])])])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render2, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
